@@ -1,18 +1,16 @@
-# =================================================================
-#          #     #                 #     #
-#          ##    #   ####   #####  ##    #  ######   #####
-#          # #   #  #    #  #    # # #   #  #          #
-#          #  #  #  #    #  #    # #  #  #  #####      #
-#          #   # #  #    #  #####  #   # #  #          #
-#          #    ##  #    #  #   #  #    ##  #          #
-#          #     #   ####   #    # #     #  ######     #
+# ==========================================================================
+#     _   _ _ ____            ____          _____
+#    | | | (_)  _ \ ___ _ __ / ___|___  _ _|_   _| __ __ _  ___ ___ _ __
+#    | |_| | | |_) / _ \ '__| |   / _ \| '_ \| || '__/ _` |/ __/ _ \ '__|
+#    |  _  | |  __/  __/ |  | |__| (_) | | | | || | | (_| | (_|  __/ |
+#    |_| |_|_|_|   \___|_|   \____\___/|_| |_|_||_|  \__,_|\___\___|_|
 #
-#       ---   The NorNet Testbed for Multi-Homed Systems  ---
-#                       https://www.nntb.no
-# =================================================================
+#       ---  High-Performance Connectivity Tracer (HiPerConTracer)  ---
+#                 https://www.nntb.no/~dreibh/hipercontracer/
+# ==========================================================================
 #
 # High-Performance Connectivity Tracer (HiPerConTracer)
-# Copyright (C) 2015-2022 by Thomas Dreibholz
+# Copyright (C) 2015-2025 by Thomas Dreibholz
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,7 +27,6 @@
 #
 # Contact: dreibh@simula.no
 
-
 # ###### Requirements #######################################################
 
 # Up-to-date GNU R installation:
@@ -91,8 +88,8 @@ traceroute <- mongo("traceroute", url = URL, options = options)
 # ====== Ping Example =======================================================
 cat("###### Ping ######\n")
 
-dateStart <- string_to_unix_time('2018-06-01 11:11:11.000000')
-dateEnd   <- string_to_unix_time('2018-06-01 11:11:12.000000')
+dateStart <- string_to_unix_time('2018-06-01 11:11:11.000000000')
+dateEnd   <- string_to_unix_time('2018-06-01 11:11:12.000000000')
 filterStart <- paste(sep="", '{ "timestamp": { "$gte" : ', sprintf("%1.0f", dateStart), ' } }')
 filterEnd   <- paste(sep="", '{ "timestamp": { "$lt" : ',  sprintf("%1.0f", dateEnd), ' } }')
 filter <- paste(sep="", '{ "$and" : [ ', filterStart, ', ', filterEnd, ' ] }')
@@ -105,8 +102,8 @@ printPingResults(pingResults)
 # ====== Traceroute Example =================================================
 cat("###### Traceroute ######\n")
 
-dateStart <- string_to_unix_time('2018-06-01 10:00:00.000000')
-dateEnd   <- string_to_unix_time('2018-06-01 10:00:01.000000')
+dateStart <- string_to_unix_time('2018-06-01 10:00:00.000000000')
+dateEnd   <- string_to_unix_time('2018-06-01 10:00:01.000000000')
 filterStart <- paste(sep="", '{ "timestamp": { "$gte" : ', sprintf("%1.0f", dateStart), ' } }')
 filterEnd   <- paste(sep="", '{ "timestamp": { "$lt" : ',  sprintf("%1.0f", dateEnd), ' } }')
 filter <- paste(sep="", '{ "$and" : [ ', filterStart, ', ', filterEnd, ' ] }')
@@ -119,15 +116,15 @@ printTracerouteResults(tracerouteResults)
 # ====== Ping with Address Search Example ===================================
 cat("###### Ping with Address Search ######\n")
 
-dateStart <- string_to_unix_time('2018-08-01 11:11:10.000000')
-dateEnd   <- string_to_unix_time('2018-08-01 11:11:15.000000')
+dateStart <- string_to_unix_time('2018-08-01 11:11:10.000000000')
+dateEnd   <- string_to_unix_time('2018-08-01 11:11:15.000000000')
 address2  <- string_to_base64_ip("158.39.4.2")
 address1  <- string_to_base64_ip("2001:700:4100:4::2")
 
 filterStart  <- paste(sep="", '{ "timestamp": { "$gte" : ', sprintf("%1.0f", dateStart), ' } }')
 filterEnd    <- paste(sep="", '{ "timestamp": { "$lt" : ',  sprintf("%1.0f", dateEnd), ' } }')
-filterA1     <- paste(sep="", '{ "source": { "$type": "0", "$binary": "', address1, '" } }')
-filterA2     <- paste(sep="", '{ "source": { "$type": "0", "$binary": "', address2, '" } }')
+filterA1     <- paste(sep="", '{ "sourceIP": { "$type": "0", "$binary": "', address1, '" } }')
+filterA2     <- paste(sep="", '{ "sourceIP": { "$type": "0", "$binary": "', address2, '" } }')
 filterA1orA2 <- paste(sep="", '{ "$or" : [ ', filterA1, ', ', filterA2, ' ] }')
 filter <- paste(sep="", '{ "$and" : [ ', filterStart, ', ', filterEnd, ', ', filterA1orA2 , ' ] }')
 cat(sep="", "Filter: ", filter, "\n")
