@@ -1,18 +1,16 @@
-// =================================================================
-//          #     #                 #     #
-//          ##    #   ####   #####  ##    #  ######   #####
-//          # #   #  #    #  #    # # #   #  #          #
-//          #  #  #  #    #  #    # #  #  #  #####      #
-//          #   # #  #    #  #####  #   # #  #          #
-//          #    ##  #    #  #   #  #    ##  #          #
-//          #     #   ####   #    # #     #  ######     #
+// ==========================================================================
+//     _   _ _ ____            ____          _____
+//    | | | (_)  _ \ ___ _ __ / ___|___  _ _|_   _| __ __ _  ___ ___ _ __
+//    | |_| | | |_) / _ \ '__| |   / _ \| '_ \| || '__/ _` |/ __/ _ \ '__|
+//    |  _  | |  __/  __/ |  | |__| (_) | | | | || | | (_| | (_|  __/ |
+//    |_| |_|_|_|   \___|_|   \____\___/|_| |_|_||_|  \__,_|\___\___|_|
 //
-//       ---   The NorNet Testbed for Multi-Homed Systems  ---
-//                       https://www.nntb.no
-// =================================================================
+//       ---  High-Performance Connectivity Tracer (HiPerConTracer)  ---
+//                 https://www.nntb.no/~dreibh/hipercontracer/
+// ==========================================================================
 //
 // High-Performance Connectivity Tracer (HiPerConTracer)
-// Copyright (C) 2015-2022 by Thomas Dreibholz
+// Copyright (C) 2015-2025 by Thomas Dreibholz
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -38,15 +36,15 @@
 class Ping : public Traceroute
 {
    public:
-   Ping(ResultsWriter*                   resultsWriter,
+   Ping(const std::string                moduleName,
+        ResultsWriter*                   resultsWriter,
+        const char*                      outputFormatName,
+        const OutputFormatVersionType    outputFormatVersion,
         const unsigned int               iterations,
         const bool                       removeDestinationAfterRun,
         const boost::asio::ip::address&  sourceAddress,
         const std::set<DestinationInfo>& destinationArray,
-        const unsigned long long         interval   =  1000,
-        const unsigned int               expiration = 10000,
-        const unsigned int               ttl        =    64,
-        const unsigned int               packetSize =     0);
+        const TracerouteParameters&      parameters);
    virtual ~Ping();
 
    virtual const std::string& getName() const;
@@ -56,12 +54,14 @@ class Ping : public Traceroute
    virtual void scheduleTimeoutEvent();
    virtual void noMoreOutstandingRequests();
    virtual bool notReachedWithCurrentTTL();
-   virtual void processResults();
    virtual void sendRequests();
+   virtual void processResults();
+
+   static int comparePingResults(const ResultEntry* a, const ResultEntry* b);
+   void writePingResultEntry(const ResultEntry* resultEntry,
+                             const char*        indentation = "");
 
    private:
-   static int comparePingResults(const ResultEntry* a, const ResultEntry* b);
-
    const std::string PingInstanceName;
 };
 
