@@ -29,17 +29,10 @@
 
 #include "worker.h"
 #include "database-configuration.h"
+#include "inputstream.h"
 #include "logger.h"
 #include "tools.h"
 
-#include <fstream>
-#include <boost/algorithm/string.hpp>
-#include <boost/iostreams/device/file_descriptor.hpp>
-#include <boost/iostreams/filter/bzip2.hpp>
-#include <boost/iostreams/filter/gzip.hpp>
-#include <boost/iostreams/filter/lzma.hpp>
-#include <boost/iostreams/stream.hpp>
-
 
 // ###### Constructor #######################################################
 Worker::Worker(const unsigned int           workerID,
@@ -114,49 +107,16 @@ void Worker::processFile(DatabaseClientBase&          databaseClient,
    }
 
    else {
-      // ====== Open input file =============================================
-#ifdef POSIX_FADV_SEQUENTIAL
-      // With fadvise() to optimise caching:
-      int handle = open(dataFile.string().c_str(), 0, O_RDONLY);
-      if(handle < 0) {
-         HPCT_LOG(warning) << getIdentification() << ": Unable to open input file "
-                           << relativeTo(dataFile, ImporterConfig.getImportFilePath());
+      // ====== Open input stream ===========================================
+      InputStream inputStream;
+      try {
+         inputStream.openStream(dataFile);
+      }
+      catch(std::exception& e) {
+         HPCT_LOG(fatal) << "Failed to open input file "
+                         << relativeTo(dataFile, ImporterConfig.getImportFilePath()) << ": " << e.what();
          return;
       }
-      if(posix_fadvise(handle, 0, 0, POSIX_FADV_SEQUENTIAL|POSIX_FADV_WILLNEED|POSIX_FADV_NOREUSE) < 0) {
-         HPCT_LOG(warning) << "posix_fadvise() failed:" << strerror(errno);
-      }
-
-      boost::iostreams::stream_buffer<boost::iostreams::file_descriptor_source> fstreambuffer(
-         handle,
-         boost::iostreams::file_descriptor_flags::close_handle);
-      std::istream inputFile(&fstreambuffer);
-#else
-#warning Without fadvise()
-      // Without fadvise():
-      std::ifstream inputFile;
-      inputFile.open(dataFile, std::ios_base::in | std::ios_base::binary);
-      if(!inputFile.is_open()) {
-         HPCT_LOG(warning) << getIdentification() << ": Unable to open input file "
-                           << relativeTo(dataFile, ImporterConfig.getImportFilePath());
-         return;
-      }
-#endif
-
-      // ====== Prepare input stream ========================================
-      boost::iostreams::filtering_istream inputStream;
-      std::string                         extension(dataFile.extension());
-      boost::algorithm::to_lower(extension);
-      if(extension == ".xz") {
-         inputStream.push(boost::iostreams::lzma_decompressor());
-      }
-      else if(extension == ".bz2") {
-         inputStream.push(boost::iostreams::bzip2_decompressor());
-      }
-      else if(extension == ".gz") {
-         inputStream.push(boost::iostreams::gzip_decompressor());
-      }
-      inputStream.push(inputFile);
 
       // ====== Read contents ============================================
       Reader.parseContents(databaseClient, rows, dataFile, inputStream);
@@ -338,6 +298,23 @@ bool Worker::importFiles(const std::list<std::filesystem::path>& dataFileList)
       // The database connection is broken -> reconnect.
    }
 
+   //  ====== Other error (e.g. decompression) ==============================
+   // NOTE: The database connection is still okay!
+   catch(std::exception& exception) {
+      HPCT_LOG(warning) << getIdentification() << ": Import in "
+                        << ((fastMode == true) ? "fast" : "slow") << " mode failed with generic error: "
+                        << exception.what();
+      try {
+         DatabaseClient.rollback();
+         if(!fastMode) {
+            finishedFile(dataFile, false);
+         }
+         return false;
+      }
+      catch(ResultsDatabaseException& exception) {
+         // Now, the database connection is broken -> reconnect.
+      }
+   }
 
    // ====== Reconnect ======================================================
    HPCT_LOG(warning) << getIdentification() << ": Waiting " << DatabaseConfig.getReconnectDelay() << " ...";
